@@ -7,6 +7,7 @@ as.Bwiqid <- function(object, ...) UseMethod("as.Bwiqid")
 as.Bwiqid.default <- function(object, ...) {
     stop(paste("No applicable method for class", class(object)))
 }
+# ...................................................................
 
 # Class Bwiqid (catches errors and allows header, defaultPlot to be changed)
 as.Bwiqid.Bwiqid <- function(object, header, defaultPlot, ...) {
@@ -17,18 +18,43 @@ as.Bwiqid.Bwiqid <- function(object, header, defaultPlot, ...) {
     attr(out, "defaultPlot") <- defaultPlot
   return(out)
 }
+# ................................................................
 
-# Class data.frame 
-as.Bwiqid.data.frame <- function(object, header, defaultPlot, ...) {
+# Class data.frame
+as.Bwiqid.data.frame <- function(object, header, defaultPlot, n.chains=1,
+    Rhat=TRUE, n.eff=TRUE, ...) {
+  npar <- length(object)
   out <- object
   class(out) <- c("Bwiqid", class(out))
   if(!missing(header))
     attr(out, "header") <- header
-  attr(out, "n.chains") <- 1
   if(!missing("defaultPlot"))
     attr(out, "defaultPlot") <- defaultPlot
+  attr(out, "n.chains") <- n.chains
+
+  if(n.chains > 1) {
+    if(is.logical(Rhat)) {
+      if(Rhat)
+        attr(out, "Rhat") <- simpleRhat(out, n.chains=n.chains)
+    } else if(is.numeric(Rhat) && length(Rhat) == npar) {
+      attr(out, "Rhat") <- Rhat
+    } else {
+      warning("'Rhat' must be logical, or a vector with a value for each column.",
+        call.=FALSE)
+    }
+  }
+  if(is.logical(n.eff)) {
+    if(n.eff)
+      attr(out, "n.eff") <- safeNeff(out)
+  } else if(is.numeric(n.eff) && length(n.eff) == npar) {
+    attr(out, "n.eff") <- n.eff
+  } else {
+    warning("'n.eff' must be logical, or a vector with a value for each column.",
+      call.=FALSE)
+  }
   return(out)
 }
+# .......................................................................
 
 # Class mcmc.list from (inter alia) rjags package
 as.Bwiqid.mcmc.list <- function(object, header, defaultPlot, ...) {
@@ -38,16 +64,16 @@ as.Bwiqid.mcmc.list <- function(object, header, defaultPlot, ...) {
   if(!missing(header))
     attr(out, "header") <- header
   attr(out, "n.chains") <- length(object)
-  attr(out, "n.eff") <- effectiveSize(object)
+  attr(out, "n.eff") <- safeNeff(out)
   if(length(object) > 1) {
-    gd <- try(gelman.diag(object, autoburnin=FALSE, multivariate=FALSE))
-    if(!inherits(gd, "try-error"))
-      attr(out, "Rhat") <- gd$psrf[, 1]
+    attr(out, "Rhat") <- simpleRhat(out, n.chains=length(object))
   }
   if(!missing("defaultPlot"))
     attr(out, "defaultPlot") <- defaultPlot
   return(out)
 }
+# '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
+
 # Class mcmc
 as.Bwiqid.mcmc <- function(object, header, defaultPlot, ...) {
   out <- as.data.frame(as.matrix(object))
@@ -56,11 +82,12 @@ as.Bwiqid.mcmc <- function(object, header, defaultPlot, ...) {
   if(!missing(header))
     attr(out, "header") <- header
   attr(out, "n.chains") <- 1
-  attr(out, "n.eff") <- effectiveSize(object)
+  attr(out, "n.eff") <- safeNeff(out)
   if(!missing("defaultPlot"))
     attr(out, "defaultPlot") <- defaultPlot
   return(out)
 }
+# ''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
 # Class bugs from R2WinBUGS package and R2OpenBUGS
 as.Bwiqid.bugs <- function(object, header, defaultPlot, ...) {
@@ -71,19 +98,14 @@ as.Bwiqid.bugs <- function(object, header, defaultPlot, ...) {
     header <- paste("Model fitted in", object$program)
   attr(out, "header") <- header
   attr(out, "n.chains") <- object$n.chains
-  if(object$n.chains > 1) {
-    if(ncol(out) > 1) {
-      attr(out, "n.eff") <- object$summary[, 'n.eff']
-      attr(out, "Rhat") <- object$summary[, 'Rhat']
-    } else {
-      attr(out, "n.eff") <- object$summary['n.eff'] # summary is a vector
-      attr(out, "Rhat") <- object$summary['Rhat']
-    }
-  }
+  if(object$n.chains > 1)
+    attr(out, "Rhat") <- simpleRhat(out, n.chains=object$n.chains)
+  attr(out, "n.eff") <- safeNeff(out)
   if(!missing("defaultPlot"))
     attr(out, "defaultPlot") <- defaultPlot
   return(out)
 }
+# '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
 # Class rjags from R2jags package
 as.Bwiqid.rjags <- function(object, header, defaultPlot, ...) {
@@ -94,35 +116,35 @@ as.Bwiqid.rjags <- function(object, header, defaultPlot, ...) {
     header <- "Model fitted in JAGS with R2jags"
   attr(out, "header") <- header
   attr(out, "n.chains") <- object$BUGSoutput$n.chains
-  if(object$BUGSoutput$n.chains > 1) {
-    attr(out, "n.eff") <- object$BUGSoutput$summary[, 'n.eff'] ## not calculated if 1 chain
-    attr(out, "Rhat") <- object$BUGSoutput$summary[, 'Rhat']
-  }
+  if(object$BUGSoutput$n.chains > 1)
+    attr(out, "Rhat") <- simpleRhat(out, n.chains=object$BUGSoutput$n.chains)
+  attr(out, "n.eff") <- safeNeff(out)
   if(!missing("defaultPlot"))
     attr(out, "defaultPlot") <- defaultPlot
   return(out)
 }
+# '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
 # Class jagsUI from jagsUI package
 as.Bwiqid.jagsUI <- function(object, header, defaultPlot, ...) {
   stopifnot(class(object$samples) == "mcmc.list")
   out <- as.data.frame(as.matrix(object$samples))
   names(out) <- fixNames(names(out))
+  n.chains <- length(object$samples)
   class(out) <- c("Bwiqid", class(out))
   if(missing(header))
     header <- "Model fitted in JAGS with jagsUI"
   attr(out, "header") <- header
-  attr(out, "n.chains") <- length(object$samples)
-  if(length(object$samples) > 1) {
-    attr(out, "n.eff") <- unlist(object$n.eff)
-    if(length(object) > 1)
-      attr(out, "Rhat") <- unlist(object$Rhat)
-  }
+  attr(out, "n.chains") <- n.chains
+  attr(out, "n.eff") <- safeNeff(out)
+  if(n.chains > 1)
+    attr(out, "Rhat") <- simpleRhat(out, n.chains=n.chains)
   if(!missing("defaultPlot"))
     attr(out, "defaultPlot") <- defaultPlot
   attr(out, "timetaken") <- as.difftime(object$mcmc.info$elapsed.mins, units="mins")
   return(out)
 }
+#'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
 # Class runjags from runjags package
 as.Bwiqid.runjags <- function(object, header, defaultPlot, ...) {
@@ -133,16 +155,27 @@ as.Bwiqid.runjags <- function(object, header, defaultPlot, ...) {
     header <- "Model fitted in JAGS with runjags"
   attr(out, "header") <- header
   attr(out, "n.chains") <- length(object$mcmc)
-  attr(out, "n.eff") <- as.data.frame(unclass(object$mcse))$sseff
-  attr(out, "MCerror") <- as.data.frame(unclass(object$mcse))$mcse
+  attr(out, "n.eff") <- safeNeff(out)
+  # attr(out, "MCerror") <- as.data.frame(unclass(object$mcse))$mcse
   if(length(object$mcmc) > 1)
-    attr(out, "Rhat") <- object$psrf$psrf[, 1]
+    attr(out, "Rhat") <- simpleRhat(out, n.chains=length(object$mcmc))
   if(!missing(defaultPlot))
     attr(out, "defaultPlot") <- defaultPlot
   attr(out, "timetaken") <- object$timetaken
   return(out)
 }
+# '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
-
+# An error-catching wrapper for coda::effectiveSize
+safeNeff <- function(x) {
+  # x is a data frame or matrix with a column for each parameter
+  safe1 <- function(v) {
+    tmp <- try(coda::effectiveSize(v), silent=TRUE)
+    if(inherits(tmp, "try-error"))
+      return(NA)
+    return(tmp)
+  }
+  apply(x, 2, safe1)
+}
 
 
